==> diffusion-3.0.4.tar.gz: diffusion-3.0.4/main/drivers/RPCio.cc <==
//
// RPCio.cc      : RPC Radio Support for Diffusion
// Authors       : Fabio Silva
//
// Copyright (C) 2000-2001 by the Unversity of Southern California
// $Id: RPCio.cc,v 1.2 2001/06/15 05:44:58 fabio Exp $
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License,
// version 2, as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
//
//

#include <stdio.h>
#include <stdlib.h>

#include "RPCio.hh"

RPCIO::RPCIO() : DiffusionIO()
{
  int fd;

  if ((fd = open(RPC_DEVICE_FILE, O_RDWR)) < 0){
    fprintf(stderr, "Cannot open the radiometrix device !\n");
    exit(-1);
  }

  in_fds.push_back(fd);
  out_fds.push_back(fd);
  max_in_descriptor = fd;
}

Packet RPCIO::RecvPacket(int fd)
{
  Packet incoming_packet = NULL;
  int packet_size;
  int header[(sizeof(struct hdr_diff) / sizeof(int)) + 1];

  read(fd, &header[0], sizeof(struct hdr_diff) | RPC_MSG_PEEK);

  packet_size = sizeof(struct hdr_diff) + ntohs(DATA_LEN(HDR_DIFF(&header[0])));

  incoming_packet = new int [(packet_size / sizeof(int)) + 1];

  if (incoming_packet == NULL){
    fprintf(stderr, "Cannot allocate memory for incoming packet !\n");
    exit(-1);
  }

  read(fd, incoming_packet, packet_size);

  return incoming_packet;
}

void RPCIO::SendPacket(Packet pkt, int len, int dst)
{
  list<int>::iterator itr;

  for (itr = out_fds.begin(); itr != out_fds.end(); ++itr){
    write(*itr, pkt, len);
  }
}

==> diffusion-3.0.6.tar.gz: diffusion-3.0.6/main/drivers/RPCio.cc <==
//
// RPCio.cc      : RPC Radio Support for Diffusion
// Authors       : Fabio Silva
//
// Copyright (C) 2000-2001 by the Unversity of Southern California
// $Id: RPCio.cc,v 1.3 2001/10/08 19:43:46 fabio Exp $
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License,
// version 2, as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
//
//

#include <stdio.h>
#include <stdlib.h>

#include "RPCio.hh"

RPCIO::RPCIO() : DiffusionIO()
{
  int fd;

  if ((fd = open(RPC_DEVICE_FILE, O_RDWR)) < 0){
    diffPrint(DEBUG_ALWAYS, "Cannot open the radiometrix device !\n");
    exit(-1);
  }

  in_fds.push_back(fd);
  out_fds.push_back(fd);
  max_in_descriptor = fd;
}

DiffPacket RPCIO::RecvPacket(int fd)
{
  DiffPacket incoming_packet = NULL;
  int packet_size;
  int header[(sizeof(struct hdr_diff) / sizeof(int)) + 1];

  read(fd, &header[0], sizeof(struct hdr_diff) | RPC_MSG_PEEK);

  packet_size = sizeof(struct hdr_diff) + ntohs(DATA_LEN(HDR_DIFF(&header[0])));

  incoming_packet = new int [(packet_size / sizeof(int)) + 1];

  if (incoming_packet == NULL){
    diffPrint(DEBUG_ALWAYS, "Cannot allocate memory for incoming packet !\n");
    exit(-1);
  }

  read(fd, incoming_packet, packet_size);

  return incoming_packet;
}

void RPCIO::SendPacket(DiffPacket pkt, int len, int dst)
{
  list<int>::iterator itr;

  for (itr = out_fds.begin(); itr != out_fds.end(); ++itr){
    write(*itr, pkt, len);
  }
}
